#include <bindings.dsl.h>
#include <CoreServices/CoreServices.h>

module Bindings.CoreServices.CarbonCore.Aliases where
#strict_import
import Bindings.CoreServices.CarbonCore.Files
import Bindings.CoreServices.CarbonCore.MacTypes
import Bindings.CoreServices.CarbonCore.UTCUtils

#synonym_t FSAliasInfoBitmap, <UInt32>
#num kFSAliasInfoNone
#num kFSAliasInfoVolumeCreateDate
#num kFSAliasInfoTargetCreateDate
#num kFSAliasInfoFinderInfo
#num kFSAliasInfoIsDirectory
#num kFSAliasInfoIDs
#num kFSAliasInfoFSInfo
#num kFSAliasInfoVolumeFlags

#num rAliasType

#num kARMMountVol
#num kARMNoUI
#num kARMMultVols
#num kARMSearch
#num kARMSearchMore
#num kARMSearchRelFirst
#num kARMTryFileIDFirst

#num asiZoneName
#num asiServerName
#num asiVolumeName
#num asiAliasName
#num asiParentName

#num kResolveAliasFileNoUI
#num kResolveAliasTryFileIDFirst

#if __AL_USE_OPAQUE_RECORD__
#  starttype struct AliasRecord
#    array_field hidden, <UInt8>
#  stoptype
#else
#  starttype struct AliasRecord
#    field userType , <OSType>
#    field aliasSize, CUShort
#  stoptype
#endif
#synonym_t AliasPtr   , Ptr <AliasRecord>
#synonym_t AliasHandle, Ptr <AliasPtr>

#starttype struct FSAliasInfo
#  field volumeCreateDate, <UTCDateTime>
#  field targetCreateDate, <UTCDateTime>
#  field fileType        , <OSType>
#  field fileCreator     , <OSType>
#  field parentDirID     , <UInt32>
#  field nodeID          , <UInt32>
#  field filesystemID    , <UInt16>
#  field signature       , <UInt16>
#  field volumeIsBootVolume , <Boolean>
#  field volumeIsAutomounted, <Boolean>
#  field volumeIsEjectable  , <Boolean>
#  field volumeHasPersistentFileIDs, <Boolean>
#  field isDirectory        , <Boolean>
#stoptype
#synonym_t  FSAliasInfoPtr, Ptr <FSAliasInfo>
#integral_t AliasInfoType

#if !__LP64__
#  callback  AlisFilterProcPtr, <CInfoPBPtr> -> Ptr <Boolean> -> <Ptr> -> IO <Boolean>
#  synonym_t AlisFilterUPP    , <AliasFilterProcPtr>
#endif

#callback FSAliasFilterProcPtr, Ptr <FSRef> -> Ptr <Boolean> -> <Ptr> -> IO <Boolean>

#ccall FSNewAlias         , Ptr <FSRef> -> Ptr <FSRef> -> Ptr <AliasHandle> -> IO <OSErr>
#ccall FSNewAliasMinimal  , Ptr <FSRef> -> Ptr <AliasHandle> -> IO <OSErr>
#ccall FSIsAliasFile      , Ptr <FSRef> -> Ptr <Boolean> -> Ptr <Boolean> -> IO <OSErr>
#ccall FSResolveAliasWithMountFlags, Ptr <FSRef> -> <AliasHandle> -> Ptr <FSRef> -> Ptr <Boolean> -> CULong -> IO <OSErr>
#ccall FSResolveAlias     , Ptr <FSRef> -> <AliasHandle> -> Ptr <FSRef> -> Ptr <Boolean> -> IO <OSErr>
#ccall FSResolveAliasFileWithMountFlags, Ptr <FSRef> -> <Boolean> -> Ptr <Boolean> -> Ptr <Boolean> -> CULong -> IO <OSErr>
#ccall FSResolveAliasFile , Ptr <FSRef> -> <Boolean> -> Ptr <Boolean> -> Ptr <Boolean> -> IO <OSErr>
#ccall FSFollowFinderAlias, Ptr <FSRef> -> <AliasHandle> -> <Boolean> -> Ptr <FSRef> -> Ptr <Boolean> -> IO <OSErr>
#ccall FSUpdateAlias      , Ptr <FSRef> -> Ptr <FSRef> -> <AliasHandle> -> Ptr <Boolean> -> IO <OSErr>
#ccall FSNewAliasUnicode  , Ptr <FSRef> -> Ptr <FSRef> -> <UniCharCount> -> Ptr <UniChar> -> Ptr <AliasHandle> -> Ptr <Boolean> -> IO <OSErr>
#ccall FSNewAliasMinimalUnicode, Ptr <FSRef> -> <UniCharCount> -> Ptr <UniChar> -> Ptr <AliasHandle> -> Ptr <Boolean> -> IO <OSErr>
#ccall FSNewAliasFromPath , Ptr CChar -> Ptr CChar -> <OptionBits> -> Ptr <AliasHandle> -> Ptr <Boolean> -> IO <OSStatus>
#ccall FSMatchAliasBulk   , Ptr <FSRef> -> CULong -> <AliasHandle> -> Ptr CShort -> Ptr <FSRef> -> Ptr <Boolean> -> <FSAliasFilterProcPtr> -> Ptr () -> IO <OSStatus>
#ccall FSCopyAliasInfo    , <AliasHandle> -> Ptr <HFSUniStr255> -> Ptr <HFSUniStr255> -> Ptr <CFStringRef> -> Ptr <FSAliasInfoBitmap> -> Ptr <FSAliasInfo> -> IO <OSStatus>
#ccall GetAliasSize       , <AliasHandle> -> IO <Size>
#ccall GetAliasUserType   , <AliasHandle> -> IO <OSType>
#ccall SetAliasUserType   , <AliasHandle> -> <OSType> -> IO ()
#ccall GetAliasSizeFromPtr, Ptr <AliasRecord> -> IO <Size>
#ccall GetAliasUserTypeFromPtr, Ptr <AliasRecord> -> IO <OSType>
#ccall SetAliasUserTypeWithPtr, <AliasPtr> -> <OSType> -> IO ()

#if !__LP64__
#  ccall FSMatchAlias     , Ptr <FSRef> -> CULong -> <AliasHandle> -> Ptr CShort -> Ptr <FSRef> -> Ptr <Boolean> -> <AliasFilterUPP> -> Ptr () -> IO <OSErr>
#  ccall FSMatchAliasNoUI , Ptr <FSRef> -> CULong -> <AliasHandle> -> Ptr CShort -> Ptr <FSRef> -> Ptr <Boolean> -> <AliasFilterUPP> -> Ptr () -> IO <OSErr>
#  ccall NewAlias         , Ptr <FSSpec> -> Ptr <FSSpec> -> Ptr <AliasHandle> -> IO <OSErr>
#  ccall NewAliasMinimal  , Ptr <FSSpec> -> Ptr <AliasHandle> -> IO <OSErr>
#  ccall NewAliasMinimalFromFullPath, CShort -> Ptr () -> <ConstStr32Param> -> <ConstStr31Param> -> Ptr <AliasHandle> -> IO <OSErr>
#  ccall ResolveAlias     , Ptr <FSSpec> -> <AliasHandle> -> Ptr <FSSpec> -> Ptr <Boolean> -> IO <OSErr>
#  ccall GetAliasInfo     , <AliasHandle> -> <AliasInfoType> -> <Str63> -> IO <OSErr>
#  ccall IsAliasFile      , Ptr <FSSpec> -> Ptr <Boolean> -> Ptr <Boolean> -> IO <OSErr>
#  ccall ResolveAliasWithMountFlags, Ptr <FSSpec> -> <AliasHandle> -> Ptr <FSSpec> -> Ptr <Boolean> -> CULong -> IO <OSErr>
#  ccall ResolveAliasFile , Ptr <FSSpec> -> <Boolean> -> Ptr <Boolean> -> Ptr <Boolean> -> IO <OSErr>
#  ccall ResolveAliasFileWithMountFlags, Ptr <FSSpec> -> <Boolean> -> Ptr <Boolean> -> Ptr <Boolean> -> CULong -> IO <OSErr>
#  ccall FollowFinderAlias, Ptr <FSSpec> -> <AliasHandle> -> <Boolean> -> Ptr <FSSpec> -> Ptr <Boolean> -> IO <OSErr>
#  ccall UpdateAlias      , Ptr <FSSpec> -> Ptr <FSSpec> -> <AliasHandle> -> Ptr <Boolean> -> IO <OSErr>
#  ccall MatchAlias       , Ptr <FSSpec> -> CULong -> <AliasHandle> -> Ptr CShort -> <FSSpecArrayPtr> -> Ptr <Boolean> -> <AliasFilterUPP> -> Ptr () -> IO <OSErr>
#  ccall ResolveAliasFileWithMountFlagsNoUI, Ptr <FSSpec> -> <Boolean> -> Ptr <Boolean> -> Ptr <Boolean> -> CLong -> IO <OSErr>
#  ccall MatchAliasNoUI   , Ptr <FSSpec> -> CULong -> <AliasHandle> -> Ptr CShort -> <FSSpecArrayPtr> -> Ptr <Boolean> -> <AliasFilterUPP> -> Ptr () -> IO <OSErr>
#endif